@@ -1,7 +1,6 @@
 /* exported ConnectionProperties ConnectionDetails ConnectionsList */
 
-const { GLib, GObject, Gtk } = imports.gi;
-const Tp = imports.gi.TelepathyGLib;
+const { GLib, GObject, Gtk, TelepathyGLib: Tp } = imports.gi;
 
 const { AccountsMonitor } = imports.accountsMonitor;
 const { NetworksManager } = imports.networksManager;
@@ -372,7 +371,7 @@ var ConnectionDetails = GObject.registerClass({
         this._savedRealname = params.fullname || '';
 
         if (port != defaultPort)
-            this._savedServer += ':%d'.format(port);
+            this._savedServer += `:${port}`;
 
         if (this._savedServer != account.display_name)
             this._savedName = account.display_name;
